LoggingLayer

Struct LoggingLayer 

pub struct LoggingLayer<I = DefaultLoggingInterceptor> { /* private fields */ }
LoggingLayer records every operation with log.

Logging

  • OpenDAL emits structured logs.
  • Every operation starts with a started log entry.
  • Every operation ends with one of the following statuses:
    • succeeded: The operation succeeded but might have more work to perform.
    • finished: The whole operation finished.
    • failed: The operation returned an error.
  • The default log level for expected errors is Warn.
  • The default log level for unexpected errors is Error.

Examples

let _ = Operator::new(services::Memory::default())?
    .layer(LoggingLayer::default());

Output

OpenDAL uses log internally.

To enable logging output, please set RUST_LOG:

RUST_LOG=debug ./app

To config logging output, please refer to Configure Logging:

RUST_LOG="info,opendal::services=debug" ./app

Logging Interceptor

You can implement your own logging interceptor to customize the logging behavior.

#[derive(Debug, Clone)]
struct MyLoggingInterceptor;

impl LoggingInterceptor for MyLoggingInterceptor {
    fn log(
        &self,
        info: &raw::ServiceInfo,
        operation: raw::Operation,
        context: &[(&str, &str)],
        message: &str,
        err: Option<&Error>,
    ) {
        // log something
    }
}

let _ = Operator::new(services::Memory::default())?
    .layer(LoggingLayer::new(MyLoggingInterceptor));

Implementations

Source

impl LoggingLayer

pub fn new<I: LoggingInterceptor>(logger: I) -> LoggingLayer<I>

Create the layer with specific logging interceptor.